@@ -1,7 +1,7 @@
 # """
 #     payload.py
 
-#     Copyright (c) 2013-2022 Snowplow Analytics Ltd. All rights reserved.
+#     Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.
 
 #     This program is licensed to you under the Apache License Version 2.0,
 #     and you may not use this file except in compliance with the Apache License
@@ -13,10 +13,6 @@
 #     an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 #     express or implied. See the Apache License Version 2.0 for the specific
 #     language governing permissions and limitations there under.
-
-#     Authors: Anuj More, Alex Dean, Fred Blundun, Paul Boocock
-#     Copyright: Copyright (c) 2013-2022 Snowplow Analytics Ltd
-#     License: Apache License Version 2.0
 # """
 
 import json
@@ -26,10 +22,9 @@ from snowplow_tracker.typing import PayloadDict, JsonEncoderFunction
 
 
 class Payload:
-
     def __init__(self, dict_: Optional[PayloadDict] = None) -> None:
         """
-            Constructor
+        Constructor
         """
 
         self.nv_pairs = {}
@@ -44,41 +39,42 @@ class Payload:
 
     def add(self, name: str, value: Any) -> None:
         """
-            Add a name value pair to the Payload object
+        Add a name value pair to the Payload object
         """
         if not (value == "" or value is None):
             self.nv_pairs[name] = value
 
     def add_dict(self, dict_: PayloadDict, base64: bool = False) -> None:
         """
-            Add a dict of name value pairs to the Payload object
+        Add a dict of name value pairs to the Payload object
 
-            :param  dict_:          Dictionary to be added to the Payload
-            :type   dict_:          dict(string:\\*)
+        :param  dict_:          Dictionary to be added to the Payload
+        :type   dict_:          dict(string:\\*)
         """
         for f in dict_:
             self.add(f, dict_[f])
 
     def add_json(
-            self,
-            dict_: Optional[PayloadDict],
-            encode_base64: bool,
-            type_when_encoded: str,
-            type_when_not_encoded: str,
-            json_encoder: Optional[JsonEncoderFunction] = None) -> None:
+        self,
+        dict_: Optional[PayloadDict],
+        encode_base64: bool,
+        type_when_encoded: str,
+        type_when_not_encoded: str,
+        json_encoder: Optional[JsonEncoderFunction] = None,
+    ) -> None:
         """
-            Add an encoded or unencoded JSON to the payload
+        Add an encoded or unencoded JSON to the payload
 
-            :param  dict_:                  Custom context for the event
-            :type   dict_:                  dict(string:\\*) | None
-            :param  encode_base64:          If the payload is base64 encoded
-            :type   encode_base64:          bool
-            :param  type_when_encoded:      Name of the field when encode_base64 is set
-            :type   type_when_encoded:      string
-            :param  type_when_not_encoded:  Name of the field when encode_base64 is not set
-            :type   type_when_not_encoded:  string
-            :param json_encoder:            Custom JSON serializer that gets called on non-serializable object
-            :type  json_encoder:            function | None
+        :param  dict_:                  Custom context for the event
+        :type   dict_:                  dict(string:\\*) | None
+        :param  encode_base64:          If the payload is base64 encoded
+        :type   encode_base64:          bool
+        :param  type_when_encoded:      Name of the field when encode_base64 is set
+        :type   type_when_encoded:      string
+        :param  type_when_not_encoded:  Name of the field when encode_base64 is not set
+        :type   type_when_not_encoded:  string
+        :param json_encoder:            Custom JSON serializer that gets called on non-serializable object
+        :type  json_encoder:            function | None
         """
 
         if dict_ is not None and dict_ != {}:
@@ -96,6 +92,6 @@ class Payload:
 
     def get(self) -> PayloadDict:
         """
-            Returns the context dictionary from the Payload object
+        Returns the context dictionary from the Payload object
         """
         return self.nv_pairs
