@@ -1,7 +1,7 @@
 # """
 #     redis_emitter.py
 
-#     Copyright (c) 2013-2022 Snowplow Analytics Ltd. All rights reserved.
+#     Copyright (c) 2013-2023 Snowplow Analytics Ltd. All rights reserved.
 
 #     This program is licensed to you under the Apache License Version 2.0,
 #     and you may not use this file except in compliance with the Apache License
@@ -13,10 +13,6 @@
 #     an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 #     express or implied. See the Apache License Version 2.0 for the specific
 #     language governing permissions and limitations there under.
-
-#     Authors: Anuj More, Alex Dean, Fred Blundun, Paul Boocock
-#     Copyright: Copyright (c) 2013-2022 Snowplow Analytics Ltd
-#     License: Apache License Version 2.0
 # """
 
 import json
@@ -38,16 +34,19 @@ logger.setLevel(logging.INFO)
 
 class RedisEmitter(object):
     """
-        Sends Snowplow events to a Redis database
+    Sends Snowplow events to a Redis database
     """
+
     if _REDIS_OPT:
 
-        def __init__(self, rdb: Optional[RedisProtocol] = None, key: str = "snowplow") -> None:
+        def __init__(
+            self, rdb: Optional[RedisProtocol] = None, key: str = "snowplow"
+        ) -> None:
             """
-                :param rdb:  Optional custom Redis database
-                :type  rdb:  redis | None
-                :param key:  The Redis key for the list of events
-                :type  key:  string
+            :param rdb:  Optional custom Redis database
+            :type  rdb:  redis | None
+            :param key:  The Redis key for the list of events
+            :type  key:  string
             """
             if rdb is None:
                 rdb = redis.StrictRedis()
@@ -57,8 +56,8 @@ class RedisEmitter(object):
 
         def input(self, payload: PayloadDict) -> None:
             """
-                :param payload:  The event properties
-                :type  payload:  dict(string:*)
+            :param payload:  The event properties
+            :type  payload:  dict(string:*)
             """
             logger.debug("Pushing event to Redis queue...")
             self.rdb.rpush(self.key, json.dumps(payload))
@@ -72,6 +71,10 @@ class RedisEmitter(object):
 
     else:
 
-        def __new__(cls, *args: Any, **kwargs: Any) -> 'RedisEmitter':
-            logger.error("RedisEmitter is not available. Please install snowplow-tracker with redis extra dependency.")
-            raise RuntimeError('RedisEmitter is not available. To use: `pip install snowplow-tracker[redis]`')
+        def __new__(cls, *args: Any, **kwargs: Any) -> "RedisEmitter":
+            logger.error(
+                "RedisEmitter is not available. Please install snowplow-tracker with redis extra dependency."
+            )
+            raise RuntimeError(
+                "RedisEmitter is not available. To use: `pip install snowplow-tracker[redis]`"
+            )
